==> jc-1.4.0.tar.gz: javax/swing/KeyStroke.h <==
// public class javax.swing.KeyStroke

// class file dependencies
// @dep_class 18f1e847d2f3b41b java_awt_AWTKeyStroke
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 965799cf10ddf9e4 javax_swing_KeyStroke

// header file dependencies
// @dep_header java_awt_AWTKeyStroke

#include "java/awt/AWTKeyStroke.h"

#ifndef _JC_javax_swing_KeyStroke_H_
#define _JC_javax_swing_KeyStroke_H_

// Forward structure declarations
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Character$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_KeyStroke$object;

// Typedefs
typedef struct _jc_javax_swing_KeyStroke$sub_refs	_jc_javax_swing_KeyStroke$sub_refs;
typedef struct _jc_javax_swing_KeyStroke$sub_nonrefs	_jc_javax_swing_KeyStroke$sub_nonrefs;
typedef struct _jc_javax_swing_KeyStroke$refs	_jc_javax_swing_KeyStroke$refs;
typedef struct _jc_javax_swing_KeyStroke$nonrefs	_jc_javax_swing_KeyStroke$nonrefs;
typedef struct _jc_javax_swing_KeyStroke$object	_jc_javax_swing_KeyStroke$object;

typedef struct _jc_javax_swing_KeyStroke$fields_struct	_jc_javax_swing_KeyStroke$fields_struct;
typedef const struct _jc_javax_swing_KeyStroke$vmethods	_jc_javax_swing_KeyStroke$vmethods;
typedef const struct _jc_javax_swing_KeyStroke$vtable	_jc_javax_swing_KeyStroke$vtable;
typedef const struct _jc_javax_swing_KeyStroke$vtype	_jc_javax_swing_KeyStroke$vtype;

// Class fields structure
struct _jc_javax_swing_KeyStroke$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24swing__24KeyStroke;
	jlong	serialVersionUID;
};
extern _jc_javax_swing_KeyStroke$fields_struct _jc_javax_swing_KeyStroke$class_fields;

// Constructors
extern void _jc_javax_swing_KeyStroke$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_KeyStroke$object *);
extern void _jc_javax_swing_KeyStroke$method$_init$ff53ff540ee83c35(_jc_env *, struct _jc_javax_swing_KeyStroke$object *, jchar, jint, jint, jboolean);

// Static methods
extern void _jc_javax_swing_KeyStroke$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_swing_KeyStroke$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$3f0973543135ea0f(_jc_env *, jchar);
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$dda373e12bf3d9d0(_jc_env *, jchar, jboolean);
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$f4d8ae8d39467db4(_jc_env *, jint, jint);
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$3a7512d5a819fae0(_jc_env *, jint, jint, jboolean);
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$478990f06351edd3(_jc_env *, struct _jc_java_lang_Character$object *, jint);
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$3825d84c6ced031b(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStrokeForEvent$238b2a67a9611df7(_jc_env *, struct _jc_java_awt_event_KeyEvent$object *);

// Virtual methods structure
struct _jc_javax_swing_KeyStroke$vmethods {
};

// Vtable
struct _jc_javax_swing_KeyStroke$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AWTKeyStroke$vmethods	java_awt_AWTKeyStroke;
	_jc_javax_swing_KeyStroke$vmethods	javax_swing_KeyStroke;
};

// Vtype
struct _jc_javax_swing_KeyStroke$vtype {
	_jc_type			type;
	_jc_javax_swing_KeyStroke$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_KeyStroke$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_KeyStroke$refs {
    _jc_javax_swing_KeyStroke$sub_refs	javax_swing_KeyStroke;
    _jc_java_awt_AWTKeyStroke$sub_refs	java_awt_AWTKeyStroke;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_KeyStroke$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_KeyStroke$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AWTKeyStroke$sub_nonrefs	java_awt_AWTKeyStroke;
    _jc_javax_swing_KeyStroke$sub_nonrefs	javax_swing_KeyStroke;
};

// Object instance structure
struct _jc_javax_swing_KeyStroke$object {
	_jc_javax_swing_KeyStroke$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_KeyStroke$vtype	*vtype;
	_jc_javax_swing_KeyStroke$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_KeyStroke$vtype _jc_javax_swing_KeyStroke$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_KeyStroke, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_KeyStroke$class_object;

#endif	/* _JC_javax_swing_KeyStroke_H_ */

==> jc-1.4.5.tar.gz: javax/swing/KeyStroke.h <==
// public class javax.swing.KeyStroke

// class file dependencies
// @dep_class e6dd86d431fa024 java_awt_AWTKeyStroke
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 965799cf10ddf9e4 javax_swing_KeyStroke

// header file dependencies
// @dep_header java_awt_AWTKeyStroke

#include "java/awt/AWTKeyStroke.h"

#ifndef _JC_javax_swing_KeyStroke_H_
#define _JC_javax_swing_KeyStroke_H_

// Forward structure declarations
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Character$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_KeyStroke$object;

// Typedefs
typedef struct _jc_javax_swing_KeyStroke$sub_refs	_jc_javax_swing_KeyStroke$sub_refs;
typedef struct _jc_javax_swing_KeyStroke$sub_nonrefs	_jc_javax_swing_KeyStroke$sub_nonrefs;
typedef struct _jc_javax_swing_KeyStroke$refs	_jc_javax_swing_KeyStroke$refs;
typedef struct _jc_javax_swing_KeyStroke$nonrefs	_jc_javax_swing_KeyStroke$nonrefs;
typedef struct _jc_javax_swing_KeyStroke$object	_jc_javax_swing_KeyStroke$object;

typedef struct _jc_javax_swing_KeyStroke$fields_struct	_jc_javax_swing_KeyStroke$fields_struct;
typedef const struct _jc_javax_swing_KeyStroke$vmethods	_jc_javax_swing_KeyStroke$vmethods;
typedef const struct _jc_javax_swing_KeyStroke$vtable	_jc_javax_swing_KeyStroke$vtable;
typedef const struct _jc_javax_swing_KeyStroke$vtype	_jc_javax_swing_KeyStroke$vtype;

// Class fields structure
struct _jc_javax_swing_KeyStroke$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24swing__24KeyStroke;
	jlong	serialVersionUID;
};
extern _jc_javax_swing_KeyStroke$fields_struct _jc_javax_swing_KeyStroke$class_fields;

// Constructors
extern void _jc_javax_swing_KeyStroke$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_KeyStroke$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_KeyStroke$method$_init$ff53ff540ee83c35(_jc_env *, struct _jc_javax_swing_KeyStroke$object *, jchar, jint, jint, jboolean) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_swing_KeyStroke$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_swing_KeyStroke$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$3f0973543135ea0f(_jc_env *, jchar) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$dda373e12bf3d9d0(_jc_env *, jchar, jboolean) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$f4d8ae8d39467db4(_jc_env *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$3a7512d5a819fae0(_jc_env *, jint, jint, jboolean) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$478990f06351edd3(_jc_env *, struct _jc_java_lang_Character$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStroke$3825d84c6ced031b(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_KeyStroke$object *_jc_javax_swing_KeyStroke$method$getKeyStrokeForEvent$238b2a67a9611df7(_jc_env *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_KeyStroke$vmethods {
};

// Vtable
struct _jc_javax_swing_KeyStroke$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AWTKeyStroke$vmethods	java_awt_AWTKeyStroke;
	_jc_javax_swing_KeyStroke$vmethods	javax_swing_KeyStroke;
};

// Vtype
struct _jc_javax_swing_KeyStroke$vtype {
	_jc_type			type;
	_jc_javax_swing_KeyStroke$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_KeyStroke$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_KeyStroke$refs {
    _jc_javax_swing_KeyStroke$sub_refs	javax_swing_KeyStroke;
    _jc_java_awt_AWTKeyStroke$sub_refs	java_awt_AWTKeyStroke;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_KeyStroke$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_KeyStroke$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AWTKeyStroke$sub_nonrefs	java_awt_AWTKeyStroke;
    _jc_javax_swing_KeyStroke$sub_nonrefs	javax_swing_KeyStroke;
};

// Object instance structure
struct _jc_javax_swing_KeyStroke$object {
	_jc_javax_swing_KeyStroke$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_KeyStroke$vtype	*vtype;
	_jc_javax_swing_KeyStroke$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_KeyStroke$vtype _jc_javax_swing_KeyStroke$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_KeyStroke, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_KeyStroke$class_object;

#endif	/* _JC_javax_swing_KeyStroke_H_ */
